import { Component } from '@angular/core';
import { CommonNzModule } from '../../../../../../common.nz.module';

interface RowData {
  name: string;
  description: string;
  titles: string[];
  level: string;
  spot: string;
  work: string;
  equipment: string;
  jobs: string[];
  reasons: string[];
  groupLevel: string;
  ltdLevel: string;
  enterpriseLevel: string;
  empty: string;
  enterprise: string;
}

const levelMap: Record<string, { color: string; text: string }> = {
  R1: {
    color: '#FE0707',
    text: '重大风险',
  },
  R2: {
    color: '#FF914D',
    text: '较大风险',
  },
  'R2*': {
    color: '#FF914D',
    text: '较大风险',
  },
  R3: {
    color: '#FFD666',
    text: '一般风险',
  },
  R4: {
    color: '#0177FB',
    text: '低风险',
  },
};

const getRandomLevel = () => {
  return Object.keys(levelMap)[Math.floor(Math.random() * Object.keys(levelMap).length)];
};

const getRowData = (): RowData => ({
  name: '',
  description: `车站轨行区封闭设施不完备
或施工人员在轨行区施工、
行走、坐卧等可能导致列车
撞击伤亡或中断行车`,
  titles: ['行车事故', '人身伤亡'],
  level: getRandomLevel(),
  spot: '上课官站',
  work: 'XX作业',
  equipment: '轨道设备',
  jobs: ['施工人员', '轨道车司机'],
  reasons: ['车站设施设备因素', '乘客自身原因'],
  groupLevel: 'Ⅱ',
  ltdLevel: 'Ⅱ',
  enterpriseLevel: 'Ⅱ',
  empty: '无',
  enterprise: '加共开单位',
});

@Component({
  selector: 'update-record-detail',
  standalone: true,
  imports: [CommonNzModule],
  templateUrl: './detail.component.html',
  styleUrl: './detail.component.less',
})
export class DetailComponent {
  tableData: RowData[] = Array.from({ length: 10 }).map(() => getRowData());
  levelMap = levelMap;

  getLevelText(level: string) {
    return this.levelMap[level]?.text;
  }

  getLevelColor(level: string) {
    return this.levelMap[level]?.color;
  }
}
