import { Component } from '@angular/core';
import { CommonNzModule } from '../../../../../common.nz.module';
import { StarIconComponent } from '../../../../../shared/star/star.icon';

interface TableRowData {
  name: string;
  color: string;
  responsibility: string;
  standard: string;
}

const colorMap: Record<string, string> = {
  '红色': '#FF0000',
  '橙色': '#EB5D00',
  '黄色': '#FBE800',
  '蓝色': '#4677F2',
};

@Component({
  selector: 'knowledge-risk-level',
  standalone: true,
  imports: [CommonNzModule, StarIconComponent],
  templateUrl: './risk-level.component.html',
  styleUrl: './risk-level.component.less',
})
export class RiskLevelComponent {
  colorMap = colorMap;

  tableData: TableRowData[] = [
    {
      name: '重大风险：R1',
      color: '红色',
      responsibility: '由集团级、公司级、部门/中心级、班组（车站）级4个层级按各自职责要求，落实具体管控措施',
      standard: '频繁的出现严重后果事件或发现存在隐患或有明显不满足的趋势，可定为红色风险条目',
    },
    {
      name: '较大风险：R2',
      color: '橙色',
      responsibility: '由公司级、部门/中心级、班组（车站）级3个层级按各自职责要求，落实具体管控措施',
      standard: '偶而的出现严重后果事件或发现存在隐患或有明显不满足的趋势，可定为橙色风险条目',
    },
    {
      name: '特殊较大风险：R2*',
      color: '橙色',
      responsibility: '由公司级、部门/中心级、班组（车站）级3个层级按各自职责要求，落实具体管控措施',
      standard: '偶而的出现严重后果事件或发现存在隐患或有明显不满足的趋势，可定为橙色风险条目',
    },
    {
      name: '一般风险：R3',
      color: '黄色',
      responsibility: '由部门/中心级、班组（车站）级2个层级按各自职责要求，落实具体管控措施',
      standard: '极少的出现严重后果事件或发现存在隐患或有明显不满足的趋势，可定为黄色风险条目',
    },
    {
      name: '低风险：R4',
      color: '蓝色',
      responsibility: '由班组（车站）级直接负责落实具体管控措施',
      standard: '基本没出现严重后果事件或发现存在隐患或有明显不满足的趋势，可定为蓝色风险条目',
    },
  ];
}
